vmshepherd.presets package
==========================

Submodules
----------

vmshepherd.presets.abstract module
----------------------------------

.. automodule:: vmshepherd.presets.abstract
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.presets.directory\_driver module
-------------------------------------------

.. automodule:: vmshepherd.presets.directory_driver
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.presets.gitrepo\_driver module
-----------------------------------------

.. automodule:: vmshepherd.presets.gitrepo_driver
    :members:
    :undoc-members:
    :show-inheritance:

vmshepherd.presets.preset module
--------------------------------

.. automodule:: vmshepherd.presets.preset
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vmshepherd.presets
    :members:
    :undoc-members:
    :show-inheritance:
